@@ -83,7 +83,7 @@ def flashMessage(cookie_name='flash', allowed_message_types=['good', 'normal', '
             )
 
             # Populate service.flash
-            cookie = get_cookie(service.http.environ.get('HTTP_COOKIE', ''), name=cookie_name)
+            cookie = get_cookie(service.environ.get('HTTP_COOKIE', ''), name=cookie_name)
             if cookie:
                 result = decode_flash(cookie)
                 service[name]['message'] = result['message']
@@ -94,7 +94,7 @@ def flashMessage(cookie_name='flash', allowed_message_types=['good', 'normal', '
             if service[name]['_set_cookie']:
                 message_type, message = service[name]['_set_cookie'][0]
                 # Remove any other cookie with the same name
-                unset_cookie(cookie_name, headers=service.http.response.headers, path='/', domain=None)
+                unset_cookie(cookie_name, header_list=service.http_response.header_list, path='/', domain=None)
                 # Set the new one
                 cookie = set_cookie(
                     key=cookie_name, 
@@ -104,11 +104,11 @@ def flashMessage(cookie_name='flash', allowed_message_types=['good', 'normal', '
                         allowed_message_types
                     ), 
                 )
-                service.http.response.headers.append(('Set-Cookie', cookie))
+                service.http_response.header_list.append(dict(name='Set-Cookie', value=cookie))
                 log.debug('Set flash message response cookie: %r', cookie)
             elif service[name]['_remove_cookie']:
                 cookie = delete_cookie(cookie_name, path='/', domain=None)
-                service.http.response.headers.append(('Set-Cookie', cookie))
+                service.http_response.header_list.append(dict(name='Set-Cookie', value=cookie))
                 log.debug('Removing flash response cookie: %r', cookie)
             else:
                 log.debug('No flash message set')
